==> estateplat-common-1.2.3-20180103.012305-3-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxJyHtxx.java <==
package cn.gtmap.estateplat.model.exchange.share;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:shenjian@gtmap.cn">jane</a>
 * @version 1.0, 2016/4/12
 * @description 共享交易合同信息
 */
@Table(name = "GX_JY_HTXX")
public class GxJyHtxx implements Serializable{
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 业务号
     */
    @Id
    private String ywh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 合同号
     */
    private String hth;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 备案时间
     */
    private Date basj;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 签订时间
     */
    private Date qdsj;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 交易时间
     */
    private Date jysj;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 合同状态
     */
    private String htzt;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 交易金额
     */
    private Double jyje;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 坐落
     */
    private String zl;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 预测建筑面积
     */
    private Double ycjzmj;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 小区名称
     */
    private String xqmc;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 幢号
     */
    private String zh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 房号
     */
    private String fh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 合同类型，参考字典项
     */
    private String htlx;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 备注
     */
    private String bz;

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getHth() {
        return hth;
    }

    public void setHth(String hth) {
        this.hth = hth;
    }

    public Date getBasj() {
        return basj;
    }

    public void setBasj(Date basj) {
        this.basj = basj;
    }

    public Date getQdsj() {
        return qdsj;
    }

    public void setQdsj(Date qdsj) {
        this.qdsj = qdsj;
    }

    public Date getJysj() {
        return jysj;
    }

    public void setJysj(Date jysj) {
        this.jysj = jysj;
    }

    public String getHtzt() {
        return htzt;
    }

    public void setHtzt(String htzt) {
        this.htzt = htzt;
    }

    public Double getJyje() {
        return jyje;
    }

    public void setJyje(Double jyje) {
        this.jyje = jyje;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public Double getYcjzmj() {
        return ycjzmj;
    }

    public void setYcjzmj(Double ycjzmj) {
        this.ycjzmj = ycjzmj;
    }

    public String getXqmc() {
        return xqmc;
    }

    public void setXqmc(String xqmc) {
        this.xqmc = xqmc;
    }

    public String getZh() {
        return zh;
    }

    public void setZh(String zh) {
        this.zh = zh;
    }

    public String getFh() {
        return fh;
    }

    public void setFh(String fh) {
        this.fh = fh;
    }

    public String getHtlx() {
        return htlx;
    }

    public void setHtlx(String htlx) {
        this.htlx = htlx;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }
}

==> estateplat-common-1.2.3-20180706.080354-139-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxJyHtxx.java <==
package cn.gtmap.estateplat.model.exchange.share;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:shenjian@gtmap.cn">jane</a>
 * @version 1.0, 2016/4/12
 * @description 共享交易合同信息
 */
@Table(name = "GX_JY_HTXX")
public class GxJyHtxx implements Serializable{
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 业务号
     */
    @Id
    private String ywh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 合同号
     */
    private String hth;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 备案时间
     */
    private Date basj;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 签订时间
     */
    private Date qdsj;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 交易时间
     */
    private Date jysj;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 合同状态
     */
    private String htzt;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 交易金额
     */
    private Double jyje;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 坐落
     */
    private String zl;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 预测建筑面积
     */
    private Double ycjzmj;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 小区名称
     */
    private String xqmc;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 幢号
     */
    private String zh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 房号
     */
    private String fh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 合同类型，参考字典项
     */
    private String htlx;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 备注
     */
    private String bz;

    private String fwbm;

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getHth() {
        return hth;
    }

    public void setHth(String hth) {
        this.hth = hth;
    }

    public Date getBasj() {
        return basj;
    }

    public void setBasj(Date basj) {
        this.basj = basj;
    }

    public Date getQdsj() {
        return qdsj;
    }

    public void setQdsj(Date qdsj) {
        this.qdsj = qdsj;
    }

    public Date getJysj() {
        return jysj;
    }

    public void setJysj(Date jysj) {
        this.jysj = jysj;
    }

    public String getHtzt() {
        return htzt;
    }

    public void setHtzt(String htzt) {
        this.htzt = htzt;
    }

    public Double getJyje() {
        return jyje;
    }

    public void setJyje(Double jyje) {
        this.jyje = jyje;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public Double getYcjzmj() {
        return ycjzmj;
    }

    public void setYcjzmj(Double ycjzmj) {
        this.ycjzmj = ycjzmj;
    }

    public String getXqmc() {
        return xqmc;
    }

    public void setXqmc(String xqmc) {
        this.xqmc = xqmc;
    }

    public String getZh() {
        return zh;
    }

    public void setZh(String zh) {
        this.zh = zh;
    }

    public String getFh() {
        return fh;
    }

    public void setFh(String fh) {
        this.fh = fh;
    }

    public String getHtlx() {
        return htlx;
    }

    public void setHtlx(String htlx) {
        this.htlx = htlx;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getFwbm() {
        return fwbm;
    }

    public void setFwbm(String fwbm) {
        this.fwbm = fwbm;
    }
}
